pub struct MockPamAccessConnectorRotationConfigsApi {
PamAccessConnectorRotationConfigsApi_expectations: MockPamAccessConnectorRotationConfigsApi_PamAccessConnectorRotationConfigsApi,
}Fields
PamAccessConnectorRotationConfigsApi_expectations: MockPamAccessConnectorRotationConfigsApi_PamAccessConnectorRotationConfigsApiImplementations
Sourceimpl MockPamAccessConnectorRotationConfigsApi
impl MockPamAccessConnectorRotationConfigsApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockPamAccessConnectorRotationConfigsApi
impl MockPamAccessConnectorRotationConfigsApi
Sourcepub fn expect_delete(&mut self) -> &mut Expectation
pub fn expect_delete(&mut self) -> &mut Expectation
Create an Expectation for mocking the delete method
Sourcepub fn expect_get(&mut self) -> &mut Expectation
pub fn expect_get(&mut self) -> &mut Expectation
Create an Expectation for mocking the get method
Sourcepub fn expect_get_all(&mut self) -> &mut Expectation
pub fn expect_get_all(&mut self) -> &mut Expectation
Create an Expectation for mocking the get_all method
Sourcepub fn expect_pause(&mut self) -> &mut Expectation
pub fn expect_pause(&mut self) -> &mut Expectation
Create an Expectation for mocking the pause method
Sourcepub fn expect_post(&mut self) -> &mut Expectation
pub fn expect_post(&mut self) -> &mut Expectation
Create an Expectation for mocking the post method
Sourcepub fn expect_put(&mut self) -> &mut Expectation
pub fn expect_put(&mut self) -> &mut Expectation
Create an Expectation for mocking the put method
Sourcepub fn expect_record_manual(&mut self) -> &mut Expectation
pub fn expect_record_manual(&mut self) -> &mut Expectation
Create an Expectation for mocking the record_manual method
Sourcepub fn expect_resume(&mut self) -> &mut Expectation
pub fn expect_resume(&mut self) -> &mut Expectation
Create an Expectation for mocking the resume method
Sourcepub fn expect_rotate(&mut self) -> &mut Expectation
pub fn expect_rotate(&mut self) -> &mut Expectation
Create an Expectation for mocking the rotate method